# Lurlene
Python-based live-coding language optimised for a small number of channels

## Install
These are generic installation instructions.

### To use, permanently
The quickest way to get started is to install the current release from PyPI:
```
pip3 install --user Lurlene
```

### To use, temporarily
If you prefer to keep .local clean, install to a virtualenv:
```
python3 -m venv venvname
venvname/bin/pip install -U pip
venvname/bin/pip install Lurlene
. venvname/bin/activate
```

## API

<a id="lurlene"></a>

### lurlene

<a id="lurlene.api"></a>

### lurlene.api

<a id="lurlene.pitch"></a>

### lurlene.pitch

<a id="lurlene.scale"></a>

### lurlene.scale

